ModuleDiff

Struct ModuleDiff 

pub struct ModuleDiff {
    pub added_functions: Vec<String>,
    pub removed_functions: Vec<String>,
    pub modified_functions: Vec<FunctionDiff>,
    pub added_imports: Vec<String>,
    pub removed_imports: Vec<String>,
}
A semantic diff between two modules.

Produced by diff. Use ModuleDiff::is_empty to check for any changes and ModuleDiff::summary for a short human-readable overview.

Fields

added_functions: Vec<String>

Names of functions present in new but not old.

removed_functions: Vec<String>

Names of functions present in old but not new.

modified_functions: Vec<FunctionDiff>

Functions present in both with any change (signature, effects, body).

added_imports: Vec<String>

Imports added in new (formatted as "module::item1,item2").

removed_imports: Vec<String>

Imports removed in new (formatted as "module::item1,item2").

Implementations

Source

impl ModuleDiff

pub fn is_empty(&self) -> bool

True if the two modules are semantically identical (no changes).

pub fn summary(&self) -> String

Short human-readable summary.